==> nextcloud-14.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/es.js <==
OC.L10N.register(
    "comments",
    {
    "Edit comment" : "Editar comentario",
    "Delete comment" : "Borrar comentario",
    "New comment …" : "Nuevo comentario",
    "Post" : "Publicar",
    "Cancel" : "Cancelar",
    "[Deleted user]" : "[Usuario eliminado]",
    "Comments" : "Comentarios",
    "No comments yet, start the conversation!" : "¡No hay comentarios, empieza la conversación!",
    "More comments …" : "Más comentarios ...",
    "Save" : "Guardar",
    "Allowed characters {count} of {max}" : "Caracteres permitidos {count} de {max}",
    "Error occurred while retrieving comment with ID {id}" : "Se ha producido un error al obtener el comentario con ID {id}",
    "Error occurred while updating comment with id {id}" : "Se ha producido un error al actualizar el comentario con ID {id}",
    "Error occurred while posting comment" : "Se ha producido un error al enviar el comentario",
    "_%n unread comment_::_%n unread comments_" : ["%n comentario sin leer","%nComentarios no leídos"],
    "Comment" : "Comentar",
    "You commented" : "Has comentado",
    "%1$s commented" : "%1$s comentados",
    "{author} commented" : "{author} comentó",
    "You commented on %1$s" : "Has comentado en %1$s",
    "You commented on {file}" : "Has comentado en  {file}",
    "%1$s commented on %2$s" : "%1$s comentados en %2$s",
    "{author} commented on {file}" : "{author} comentó en {file}",
    "<strong>Comments</strong> for files" : "<strong>Comentarios</strong> para archivos",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Te han mencionado en \"{file}\", en un comentario de un usuario que después ha sido eliminado",
    "{user} mentioned you in a comment on “{file}”" : "{user} te mencionó en un comentario en “{file}”",
    "Files app plugin to add comments to files" : "Plugin de la app de Archivos para añadir comentarios a archivos.",
    "Unknown user" : "Usuario desconocido",
    "A (now) deleted user mentioned you in a comment on “%s”" : "Un usuario (ahora) eliminado, te mencionó en un comentario en “%s”",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "Un usuario (ahora) eliminado, te mencionó en un comentario en “{file}”",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s te mencionó en un comentario en “%2$s”",
    "You were mentioned on “%s”, in a comment by a user that has since been deleted" : "Te han mencionado en \"%s\", en un comentario por un usuario que después ha sido eliminado"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/es.js <==
OC.L10N.register(
    "comments",
    {
    "Edit comment" : "Editar comentario",
    "Delete comment" : "Borrar comentario",
    "New comment …" : "Nuevo comentario",
    "Post" : "Publicar",
    "Cancel" : "Cancelar",
    "[Deleted user]" : "[Usuario eliminado]",
    "Comments" : "Comentarios",
    "No comments yet, start the conversation!" : "¡No hay comentarios, empieza la conversación!",
    "More comments …" : "Más comentarios ...",
    "Save" : "Guardar",
    "Allowed characters {count} of {max}" : "Caracteres permitidos {count} de {max}",
    "Error occurred while retrieving comment with ID {id}" : "Se ha producido un error al obtener el comentario con ID {id}",
    "Error occurred while updating comment with id {id}" : "Se ha producido un error al actualizar el comentario con ID {id}",
    "Error occurred while posting comment" : "Se ha producido un error al enviar el comentario",
    "_%n unread comment_::_%n unread comments_" : ["%n comentario sin leer","%nComentarios no leídos"],
    "Comment" : "Comentar",
    "You commented" : "Has comentado",
    "%1$s commented" : "%1$s comentados",
    "{author} commented" : "{author} comentó",
    "You commented on %1$s" : "Has comentado en %1$s",
    "You commented on {file}" : "Has comentado en  {file}",
    "%1$s commented on %2$s" : "%1$s comentados en %2$s",
    "{author} commented on {file}" : "{author} comentó en {file}",
    "<strong>Comments</strong> for files" : "<strong>Comentarios</strong> para archivos",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Te han mencionado en \"{file}\", en un comentario de un usuario que después ha sido eliminado",
    "{user} mentioned you in a comment on “{file}”" : "{user} te mencionó en un comentario en “{file}”",
    "Files app plugin to add comments to files" : "Plugin de la app de Archivos para añadir comentarios a archivos.",
    "You were mentioned on “%s”, in a comment by a user that has since been deleted" : "Te han mencionado en \"%s\", en un comentario por un usuario que después ha sido eliminado",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s te mencionó en un comentario en “%2$s”"
},
"nplurals=2; plural=(n != 1);");
